Documentation
¶
Index ¶
- Variables
- func Authenticate(password string) (int, error)
- func BuildRequestTime() (float64, error)
- func Call(method string, params interface{}) (map[string]interface{}, error)
- func ClientBuildSuccess() (int, error)
- func Echo(echo string) (string, error)
- func ExploratoryBuildExpire() (int, error)
- func ExploratoryBuildExpirePercentage() (int, error)
- func ExploratoryBuildReject() (int, error)
- func ExploratoryBuildRejectPercentage() (int, error)
- func ExploratoryBuildSuccess() (int, error)
- func ExploratoryBuildSuccessPercentage() (int, error)
- func FindUpdates() (bool, error)
- func IncomingBW() (int, error)
- func Initialize(host, port, path string)
- func InitializeWithSelfSignedCert(host, port, path, cert string) error
- func KnownPeers() (int, error)
- func NetStatus() (string, error)
- func OutgoingBw() (int, error)
- func ParticipatingAverageTunnels() (int, error)
- func ParticipatingHourAverageTunnels() (int, error)
- func ParticipatingTunnels() (int, error)
- func RateStat(Stat string, Period int) (int, error)
- func RateStatExact(Stat string, Period int) (float64, error)
- func ReceiveBps() (int, error)
- func ReceiveBpsHourAverage() (int, error)
- func Reseeding() (bool, error)
- func Restart() (string, error)
- func RestartGraceful() (string, error)
- func SendBps() (int, error)
- func SendBpsHourAverage() (int, error)
- func Shutdown() (string, error)
- func ShutdownGraceful() (string, error)
- func Status() (string, error)
- func UpTime() (int64, error)
- func Update() (string, error)
- func Upnp() (string, error)
- func Version() (string, error)
Constants ¶
This section is empty.
Variables ¶
var (
RPCOpts *jsonrpc.RPCClientOpts
)
Functions ¶
func Authenticate ¶
Authenticate to the RPC API with a password
func BuildRequestTime ¶ added in v0.1.8
func ClientBuildSuccess ¶ added in v0.1.8
func ExploratoryBuildExpire ¶
func ExploratoryBuildReject ¶
func ExploratoryBuildSuccess ¶
func FindUpdates ¶
FindUpdates pings the server to check for updates
func Initialize ¶
func Initialize(host, port, path string)
Initialize set up the rpcClient with the specified host, port, and path
func InitializeWithSelfSignedCert ¶
InitializeWithSelfSignedCert will set up an rpcClient which will accept a self-signed certificate, at the path speciied by cert.
func ParticipatingAverageTunnels ¶ added in v0.1.8
func ParticipatingHourAverageTunnels ¶ added in v0.1.8
func ParticipatingTunnels ¶
ParticipatingTunnels gets the number of participating tunnels the router has currently
func ReceiveBps ¶
func ReceiveBpsHourAverage ¶ added in v0.1.8
func RestartGraceful ¶
RestartGraceful initiates a graceful restart, which will occur in around 11 minutes.
func SendBpsHourAverage ¶ added in v0.1.8
func ShutdownGraceful ¶
Shutdown initiates a graceful restart, which will occur in around 11 minutes.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.